.. rancidcmd documentation master file, created by
   sphinx-quickstart on Thu Apr  2 13:16:39 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to rancidcmd's documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 2

.. automodule:: rancidcmd
   :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

